@@ -8,12 +8,12 @@ use fil_actors_runtime::{
     actor_error, make_empty_map, make_map_with_root, resolve_to_id_addr, wasm_trampoline,
     ActorDowncast, ActorError, Map, INIT_ACTOR_ADDR,
 };
+use fvm_ipld_blockstore::Blockstore;
+use fvm_ipld_encoding::{to_vec, RawBytes};
 use fvm_shared::actor::builtin::CALLER_TYPES_SIGNABLE;
 use fvm_shared::address::Address;
 use fvm_shared::bigint::Sign;
-use fvm_shared::blockstore::Blockstore;
 use fvm_shared::econ::TokenAmount;
-use fvm_shared::encoding::{to_vec, RawBytes};
 use fvm_shared::error::ExitCode;
 use fvm_shared::{MethodNum, HAMT_BIT_WIDTH, METHOD_CONSTRUCTOR};
 use num_derive::FromPrimitive;
